@@ -1,8 +1,9 @@
 #ifndef ___MEANVARANOMALY_H___
 #define ___MEANVARANOMALY_H___
 
-#include <R.h>
-#include <Rinternals.h>
+#include <Rcpp.h>
+//#include <R.h>
+//#include <Rinternals.h>
 #include <vector>
 
 std::vector<int> MeanVarAnomaly(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
