@@ -2,8 +2,9 @@
 #ifndef ___ROBUSTMEANANOMALYMV_H___
 #define ___ROBUSTMEANANOMALYMV_H___
 
-#include <R.h>
-#include <Rinternals.h>
+#include <Rcpp.h>
+//#include <R.h>
+//#include <Rinternals.h>
 #include <vector>
 
 std::vector<int> RobustMeanAnomalyMV(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
